==> fet-5.14.2.tar.bz2: fet-5.14.2/src/interface/constraintteacherhomeroomsform.h <==
/***************************************************************************
                          constraintteacherhomeroomsform.h  -  description
                             -------------------
    begin                : 8 April 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTTEACHERHOMEROOMSFORM_H
#define CONSTRAINTTEACHERHOMEROOMSFORM_H

#include "ui_constraintteacherhomeroomsform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintTeacherHomeRoomsForm : public QDialog, Ui::ConstraintTeacherHomeRoomsForm_template  {
	Q_OBJECT
public:
	SpaceConstraintsList visibleConstraintsList;

	ConstraintTeacherHomeRoomsForm();
	~ConstraintTeacherHomeRoomsForm();

	void refreshConstraintsListBox();

	bool filterOk(SpaceConstraint* ctr);
	
public slots:
	void constraintChanged(int index);
	void addConstraint();
	void removeConstraint();
	void modifyConstraint();
	
	void filterChanged();
};

#endif

==> fet_5.38.1.orig.tar.bz2: fet-5.38.1/src/interface/constraintteacherhomeroomsform.h <==
/***************************************************************************
                          constraintteacherhomeroomsform.h  -  description
                             -------------------
    begin                : 8 April 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTTEACHERHOMEROOMSFORM_H
#define CONSTRAINTTEACHERHOMEROOMSFORM_H

#include "ui_constraintteacherhomeroomsform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintTeacherHomeRoomsForm : public QDialog, Ui::ConstraintTeacherHomeRoomsForm_template  {
	Q_OBJECT
public:
	SpaceConstraintsList visibleConstraintsList;

	ConstraintTeacherHomeRoomsForm(QWidget* parent);
	~ConstraintTeacherHomeRoomsForm();

	void refreshConstraintsListWidget();

	bool filterOk(SpaceConstraint* ctr);
	
public slots:
	void constraintChanged(int index);
	void addConstraint();
	void removeConstraint();
	void modifyConstraint();
	
	void filterChanged();
};

#endif
